# Cannadicとは非互換の品詞を持つ辞書
#
# Anthyは一部の付属語を辞書に持つので
# cannadicに入っていない単語を書いています。
#
#
#てすつ #T35*100 A\ A
#まくる
#まわる
#
#
#
#
あいそをつか #S5 #_4愛想を_2尽か
あいたいとりひき #T30 #_4相対_4取引
あいぱたーん #T35 #_2アイ_4パターン
あくせんくとうのすえ #T35 #_8悪戦苦闘の_2末
あたまかくしてしりかく #S5 #_3頭_4隠して_2尻_2隠
あつさわすれ #KS #_3熱さ_3忘れ
あってよんじゅうはっくせ #T35 #_3有って_9四十八癖
あびないはし #T35 #_4危ない_2橋
あぶらをう #R5 #_4油を_1売
あらしのまえ #T35 #_4嵐の_2前
あわおどり #T30 #_2阿波_3踊り
あんじんりゅうめい #T35 #_4安心_5立命
あんずるよりうむがやす #KY #_6案ずるより_3産むが_2易
あんだーぱー #T35 #_4アンダー_2パー
あんちういるす #T30 #_3アンチ_4ウイルス
いーぶんぱー #T35 #_4イーブン_2パー
いうはやすくおこなうはかた #KY #_3言うは_3易く_5行うは_2難
いちひめにたろう #T35 #_4一姫_4二太郎
いをとな #KS #_2異を_2唱
いがいやいがい #F06 #_4意外や_3意外
いけいのねん #T35 #_4畏敬の_2念
いじをは #R5 #_3意地を_1張
いたくもかゆくもな #KY #_4痛くも_4痒くも_1な
いちかばちか #T35 #_3一か_3八か
いちごにつ #K5 #_4一語に_1尽
いちじがばんじ #T35 #_4一事が_3万事
いちじしけん #T35 #_3一次_3試験
いちをきいてじゅうをし #R5 #_3一を_3聞いて_4十を_1知
いっしょうにふ #S5 #_6一笑に_1付
いっしをむく #W5 #_4一矢を_2報
いっしんにあつめ #KS #_5一身に_3集め
いっすんさきはやみ #T35 #_4一寸_3先は_2闇
いっすんのむしにもごぶのたましい #T35 #_5一寸の_4虫にも_3五分の_4魂
いっせんをかく #S5 #_5一線を_2画
いってのけ #KS #_3言って_2のけ
いっぽんじめ #T30 #_4一本_2締め
いてもたってもい #KS #_3いても_4立っても_1い
いなかっぺたいしょう #T30 #_5田舎っぺ_5大将
いのちあってのものだね #T35 #_3命_4あっての_4物種
いのなかのかわずたいかいをし #R5 #_2井の_3中の_3蛙_5大海を_1知
いひょうをつ #K5 #_5意表を_1つ
いわぬがはな #T35 #_4言わぬが_2花
いんすたんすか #T30 #_6インスタンス_1化
うぇぶでざいん #T30 #_3ウェブ_4デザイン
うごうのしゅう #T35 #_4烏合の_3衆
うそからでたまこと #T35 #_4嘘から_2出た_3真
うらみをか #W5 #_4怨みを_1買
うらをか #K5 #_3裏を_1か
うわさをすればかげがさ #S5 #_4噂を_3すれば_3影が_1さ
うんをてんにまか #S5 #_3運を_3天に_2任
えーがた #T35 #_2A_2型
えーびーがた #T35 #_4AB_2型
えいごこうざ #T35 #_3英語_3講座
えにかいたもち #T35 #_2絵に_3描いた_2餅
えびでたいをつ #R5 #_3海老で_3鯛を_1釣
えんはいなもの #T35 #_3縁は_2異な_2もの
おーがた #T35 #_2O_2型
おうまがとき #T35 #_4逢魔が_2時
おうようてくにっく #T35 #_4応用_5テクニック
おえらびくださ #R5 #_4お選び_3くださ
おおかれすくなかれ #CJ #_4多かれ_5少なかれ
おきゅうをすえ #KS #_5お灸を_2すえ
おしあいへしあい #T30 #_4押し合い_4へし合い
おなじあなのむじな #T35 #_3同じ_3穴の_3貉
おなじかまのめし #T35 #_3同じ_3釜の_2飯
おにかんとく #T35 #_2鬼_4監督
おにこーち #T35 #_2鬼_3コーチ
おにのいぬまにせんたく #T30 #_3鬼の_2居ぬ_2間に_4洗濯
おはちがまわ #R5 #_4お鉢が_2回
おびにみじかしたすきになが #KY #_3帯に_4短し_4襷に_2長
おもうしつけ #KS #_1御_5申しつけ
おやのこころこし #R5 #_3親の_3心_1子_1知
おやまのたいしょう #T35 #_4お山の_5大将
おんどをと #R5 #_4音頭を_1と
かいさいをさけ #B5 #_5快哉を_2叫
かいしそうそう #T35 #_3開始_4早々
かいしんのえみ #T35 #_5会心の_2笑み
かいたた #K5r #_2買い_2たた
かいものがえり #T35 #_4買いもの_3帰り
かいよりはじ #M5 #_4隗より_2始
かいわれだいこん #T35 #_4かいわれ_4大根
かおからひがで #KS #_4顔から_2火が_1出
かおがき #K5 #_3顔が_1利
かかあてんか #T35 #_3かかあ_3天下
かきくうきゃく #T35 #_2柿_2食う_3客
かくりつへんどう #T30 #_4確率_4変動
かぜのたより #T35 #_3風の_3便り
かぜのまたさぶろう #T35 #_3風の_6又三郎
かぜをひ #K5 #_3風邪を_1ひ
かたがこ #R5 #_3肩が_1凝
かたでいき #T35 #_3肩で_2息
かたでかぜをき #R5 #_3肩で_3風を_1切
かたのにがおも #KY #_5肩の荷が_2重
かってかぶとのおをしめ #KS #_3勝って_4兜の_2緒を_2締め
かってきまま #T05 #_3勝手_3気まま
かつおのたたき #T35 #_4カツオの_3タタキ
かていのいがく #T35 #_4家庭の_3医学
かなかんじへんかんえんじん #T35 #_2仮名_3漢字_4変換_4エンジン
かふくはあざなえるなわのごとし #CJ #_4禍福は_5糾える_3縄の_3如し
かべにみみありしょうじにめあ #R5r #_3壁に_2耳_2あり_5障子に_1目_1あ
かほうはねてま #T5 #_4果報は_2寝て_1待
かまをかけ #KS #_3カマを_2かけ
かみのけいじ #T35 #_3神の_3啓示
かもふか #T35 #_2可も_2不可
からしめんたいこ #T35 #_3辛子_5明太子
かわいいこにはたびをさせ #KS #_4可愛い_3子には_3旅を_2させ
かわいじゅく #KK #_3河合_3塾
かわきもの #T35 #_3乾き_2物
かんこうきぶん #T35 #_4観光_3気分
かんこうびざ #T35 #_4観光_2ビザ
かんぜんいっち #T35 #_4完全_3一致
かんにさわ #R5 #_3癇に_2障
がくなりがた #KY #_2学_2成り_2難
がりょうてんせいをか #K5 #_9画龍点睛を_1欠
きかぬはいっしょうのはじ #T35 #_4聞かぬは_6一生の_2恥
きくはいっときのはじ #T35 #_3聞くは_5一時の_2恥
きしゃのきしゃがきしゃできしゃした #T35 #_4貴社の_4記者が_4汽車で_5帰社した
きしょうがあら #KY #_5気性が_2荒
きせいれっしゃ #T35 #_3帰省_4列車
きたみち #T35 #_2来た_2道
きたよび #KK #_2北_2予備
きではなをくく #R5 #_2木で_3花を_2くく
きなこもち #T35 #_3きな粉_2もち
きもだめし #T30 #_2肝_3試し
きもにめいじ #KS #_3肝に_3銘じ
きもをつぶ #S5 #_3肝を_2つぶ
きゅうすればつうず #CJ #_6窮すれば_3通ず
きょうかいじょう #T35 #_5境界_3上
きょうがさめ #M5 #_4興が_2醒め
きょうきゅうこうしゃ #KK #_6供給_4公社
きょうこうとっぱ #T30 #_5強行_3突破
きょうさんせーる #T35 #_5協賛_3セール
きょうもきょうとて #RT #_4今日も_5今日とて
きをくば #R5 #_2気を_2配
きんだんのかじつ #T35 #_5禁断の_3果実
ぎゃくいそう #T05 #_3逆_3位相
くうきいれ #T35 #_3空気_2入れ
くぎをさ #S5 #_3釘を_1刺
くさってもたい #T35 #_5腐っても_2鯛
くさむしり #T30 #_2草_3むしり
くすりづけ #T35 #_3薬_2漬け
くちがかた #KY #_3口が_2固
くちやかまし #KY #_2口_4やかまし
くちをわ #R5 #_3口を_1割
くものこをちら #S5 #_3蜘蛛の_2子を_2散ら
くらくをともに #SX #_4苦楽を_3共に
くんしあやうきにちかづ #K5 #_3君子_5危うきに_3近付
くんしあやうきにちかよ #R5 #_3君子_5危うきに_3近寄
ぐのこっちょう #T35 #_2愚の_5骨頂
けいさんどりる #T35 #_4計算_3ドリル
けいじばいぱす #CN #_3京滋_4バイパス
けいろうのひ #T35 #_5敬老の_1日
けがのこうみょう #T35 #_3怪我の_5功名
けさまでにく #KY #_4袈裟まで_2憎
けりをつけ #KS #_3ケリを_2つけ
けんとうをつけ #KS #_5見当を_2付け
けんとうをいの #R5 #_5健闘を_2祈
げきじんさいがい #T35 #_4激甚_4災害
げきをとば #S5 #_3激を_2飛ば
げんをかつ #G5 #_3験を_2担
こーどびはいんど #T35 #_3コード_5ビハインド
こうかいさきにた #T5 #_4後悔_3先に_1立
こうかんのうれい #T35 #_5後患の_3憂い
こうがくきかい #T35 #_4光学_3器械
こうがくのうぜいしゃ #T35 #_4高額_6納税者
こうがくほせい #T30 #_4光学_3補正
こうげーむ #T35 #_2好_3ゲーム
こうさんかさよう #T35 #_2抗_3酸化_3作用
こうさんかざい #T35 #_2抗_5酸化剤
こうぼうもふでのあやま #R5r #_5弘法も_3筆の_3誤
こうみょうがつじ #T35 #_6功名が_2辻
こうらぼし #T35 #_3甲羅_2干し
こけつにいらずんば #T35 #_4虎穴に_5入らずんば
こころのそこ #T35 #_4心の_2底
こしがおも #KY #_3腰が_2重
こしをすえ #KS #_3腰を_2据え
こじをえ #KS #_3虎児を_1得
ことしのほうふ #T35 #_4今年の_3抱負
ころっけぱん #T35 #_4コロッケ_2パン
ころんでもただではおき #KS #_5転んでも_4ただでは_2起き
こんしんのちから #T35 #_5渾身の_3力
こんなはず #T05 #_3こんな_2はず
ごうにいっては #T35 #_3郷に_4入っては
ごうにしたが #W5 #_3郷に_3従
ごむとび #T30 #_2ゴム_2飛び
さいしょうさいこう #T35 #_5最小_4催行
さいしゅうがくしょう #T35 #_5最終_5楽章
さくにおぼれ #KS #_3策に_3溺れ
さけのさかな #T35 #_3酒の_3肴
さじをなげ #KS #_3さじを_2投げ #_3匙を_2投げ
さらうどん #T35 #_2皿_3うどん
さわらぬかみにたたりな #KY #_4触らぬ_3神に_3祟り_1な
さんかさよう #T35 #_3酸化_3作用
さんじゅうろっけいにげるにしかず #CJ #_9三十六計_4逃げるに_3如かず
さんだんおち #T35 #_4三段_2落ち
さんにんよらばもんじゅのちえ #T35 #_4三人_3寄らば_5文殊の_2知恵
さんぼんじめ #T30 #_4三本_2締め
ざいこいっそう #T30 #_3在庫_4一掃
ざっしきしゃ #T35 #_3雑誌_3記者
ざつだんいた #T35 #_4雑談_2板
ざんきにたえ #KS #_4慙愧に_2耐え
しーぱらだいす #KK #_2シー_5パラダイス
しきおりおり #T35 #_2四季_4折々
しさんかつよう #T30 #_3資産_4活用
しじまち #T35 #_2指示_2待ち
しじょうさいあく #T05 #_4市場_4最悪
しっくはうす #T35 #_3シック_3ハウス
しにんにくちな #KY #_4死人に_2口_1な
しばいがか #R5r #_3芝居_2がか
しふくをこや #S5 #_4私腹を_2肥や
しゅうしゅうがつ #K5 #_7収拾が_1つ
しゅうのうこもの #T35 #_5収納_3小物
しゅにまじわ #R5 #_3朱に_3交わ
しょうこりもな #KY #_6性凝りも_1無
しょうしせんばん #T35 #_4笑止_4千万
しょうじはだいじ #T35 #_5小事は_3大事
しょうにしか #T35 #_4小児_2歯科
しょうねんおいやす #KY #_5少年_2老い_2易
しょうほーる #T35 #_3小_3ホール
しょしんわするべからず #CJ #_4初心_7忘るべからず
しらぬがほとけ #T35 #_4知らぬが_3仏
しらはのや #T35 #_4白羽の_1矢
しらはのやをたて #KS #_4白羽の_2矢を_2立て
しらをき #R5 #_3しらを_1切
しらをきりとお #S5 #_3しらを_4切り通
しりにし #K5 #_3尻に_1敷
しるひとぞし #R5 #_2知る_3人ぞ_1知
しんせきろこう #T30 #_4浸漬_3露光
しんやえいぎょう #T30 #_3深夜_5営業
じかますます #T35 #_2時下_4ますます
じかんどおり #T05 #_3時間_3通り
じしんかみなりかじおやじ #T35 #_3地震_4雷_2火事_3親父
じばらをき #R5 #_4自腹を_1切
じにから #KY #_2地に_2辛
じゅうよくごうをせい #S5 #_3柔_2よく_3剛を_2制
じょーしん #KK ジョーシン
すいこうさいばい #T30 #_4水耕_4栽培
すいせいぺん #T35 #_4水性_2ペン
すいほうにき #S5 #_5水泡に_1帰
すきこそもののじょうずなれ #CJ #_4好きこそ_3物の_4上手_2なれ
すぎたるはおよばざるがごとし #T35 #_5過ぎたるは_6及ばざるが_3如し
すずめのなみだ #T35 #_4雀の_3涙
すづくり #T30 #_1巣_3作り
すなをかむおもい #T35 #_3砂を_2噛む_3思い
すめばみやこ #F02 #_3住めば_3都
すりーえむ #KK #_3スリー_2エム
ずがたか #KY #_2頭が_2高
ずにの #R5 #_2図に_1乗
せいかりれー #T35 #_3聖火_3リレー
せいかんとんねる #CN #_4青函_4トンネル
せいこうほうしゅう #T35 #_4成功_5報酬
せいこくをい #KS #_5正鵠を_1射
せいてはことをしそんじ #KS #_4急いては_3事を_4仕損じ
せいのすう #T35 #_3正の_2数
せっかせっこう #T35 #_3雪花_4石膏
せんいぎょう #T35 #_3繊維_3業
せんたくびより #T35 #_4洗濯_3日和
ぜっとかい #KK #_3Ｚ_2会
ぜにうしない #T30 #_2銭_4失い
ぜんはいそ #G5 #_3善は_2急
そですりあうもたしょうのえん #T35 #_2袖_5擦り合うも_5他生の_2縁
そなえあればうれいな #KY #_3備え_3あれば_3憂い_1な
そふとらんでぃんぐ #T35 #_3ソフト_6ランディング
そりがあ #W5 #_3反りが_1合
そんしてとくと #R5 #_4損して_2得_1取
たいりょうしいれ #T35 #_5大量_3仕入れ
たかをくく #R5 #_3高を_2くく
たていたにみず #T35 #_5立て板に_2水
たてまき #T35 #_2縦_2巻
たでくうむしもすきずき #T35 #_2蓼_2食う_3虫も_4好きずき
たびのはじはかきすて #T35 #_3旅の_3恥は_4掻き捨て
たみやもけい #KK #_3田宮_3模型
たもとをわか #T5 #_4袂を_2分か
たわいのな #KY #_4たわいの_1な
たんきはそんき #T35 #_4短気は_3損気
たんごのせっく #T35 #_4端午の_3節句
だいさんせくたー #T35 #_4第三_4セクター
だいなりしょうなり #F14 #_4大なり_5小なり
だいはしょうをかね #KS #_3大は_4小を_2兼ね
だいほーる #T35 #_2大_3ホール
だいよび #KK #_2大_2予備
だぶるべっど #T35 #_3ダブル_3ベッド
だぶるりーち #T30 #_3ダブル_3リーチ
ちぇーんてん #T35 #_4チェーン_2店
ちくばのとも #T35 #_4竹馬の_2友
ちこうよ #R5 #_3近う_1寄
ちもなみだ #T35 #_2血も_3涙
ちょういけてる #T35 #_3超_4いけてる
ちょうみにすか #T35 #_3超_4ミニスカ
ちりもつもればやまとな #R5 #_3塵も_4積もれば_3山と_1な
ちんもくはきん #T35 #_5沈黙は_2金
つうしんからおけ #T35 #_4通信_4カラオケ
つけだれ #T35 #_2つけ_2ダレ
つごうがつ #K5 #_4都合が_1付
つのをためてうしをころ #S5 #_3角を_3矯めて_3牛を_2殺
つぼにはま #R5 #_3ツボに_2はま
つよきをくじ #K5 #_4強きを_2くじ
つらのかわがあつ #KY #_3面の_3皮が_2厚
ていはんぱつ #T35 #_2低_4反発
てしおにかけ #KS #_4手塩に_2かけ
てつはあついうちにう #T5 #_3鉄は_3熱い_3うちに_1打
てにおえ #KS #_2手に_2負え
てふろんかこう #T35 #_4テフロン_3加工
てをかえしなをかえ #KS #_2手を_2替え_3品を_2替え
てをそめ #R5 #_2手を_2染め
てんちいんでっくす #T35 #_3転置_6インデックス
てんとうとりひき #T30 #_4店頭_4取引
てんはみずからたすくるものをたすく #CJ #_3天は_4自ら_4助くる_3者を_3助く
てんねんおんせん #T35 #_4天然_4温泉
でぶせん #T35 #_2デブ_2専
とうきゅうはんず #KK #_5東急_3ハンズ
とうしひ #T35 #_3投資_1費
とうをえ #KS #_3当を_1得
ところかわればしなかわ #R5 #_3所_4変われば_2品_2変わ
とちしんわ #T35 #_2土地_3神話
とっぷてん #T35 #_3トップ_2テン
とっぷもでる #T35 #_3トップ_3モデル
とほうにくれ #KS #_4途方に_2暮れ
とらぎ #T35 #_2トラ_1技
とらぶるめーかー #T35 #_4トラブル_4メーカー
とりのおりんぴっく #T35 #_3トリノ_6オリンピック
とんびがたかをう #M5 #_4鳶が_3鷹を_1生
どうけいのいたり #T05 #_5同慶の_3至り
どうとでもな #R5 #_5どうとでも_1な
どうにい #R5 #_3堂に_1入
どうにでもな #R5 #_5どうにでも_1な
どくしゃもでる #T35 #_4読者_3モデル
どくをくらわばさら #T35 #_3毒を_4食らわば_2皿
どりんくざい #T35 #_4ドリンク_2剤
ないそではふ #R5 #_2無い_3袖は_1振
なかずと #B5 #_3鳴かず_1飛
なかつぎとうしゅじん #T35 #_4中継_4投手_2陣
なきっつらにはち #T35 #_6泣きっ面に_2蜂
なくこはそだ #T5 #_2泣く_2子は_2育
なくこもだま #R5 #_2泣く_2子も_2黙
なくてななくせ #T35 #_3無くて_4七癖
なさけはひとのためな #R5 #_4情けは_3人の_2為_1な
なはたいをあらわ #S5 #_2名は_3体を_3表
なやみのたね #T35 #_4悩みの_2タネ
なるにあこく #T35 #_4ナルニア_2国
にこにこどうが #KK #_4ニコニコ_3動画
にとをおうものはいっとをもえ #KS #_3二兎を_2追う_3ものは_5一兎をも_1得
にどあることはさんどあ #R5 #_2二度_2ある_3ことは_3三度_1あ
にのあしをふ #M5 #_5二の足を_1踏
にもつもち #T35 #_3荷物_2持ち
ねたこをおこ #S5 #_2寝た_2子を_2起こ
ねぶたまつり #T35 #_3ねぶた_3祭
ねをあげ #KS #_2音を_2上げ
ねをおろ #S5 #_2根を_2下ろ
ねんじゅうむきゅう #T35 #_5年中_4無休
のーかっと #T35 #_2ノー_3カット
のうあるたかはつめかく #S5 #_2能_2ある_3鷹は_2爪_2隠
のうあるたかはつめをかく #S5 #_2能_2ある_3鷹は_3爪を_2隠
のこりものにはふく #T35 #_7残り物には_2福
のどからてがで #KS #_4喉から_2手が_1出
のどもとすぎ #R5 #_4喉元_2過ぎ
のれんにうでおし #T35 #_4暖簾に_2腕_2押し
はーどらんでぃんぐ #T30 #_3ハード_6ランディング
はいごうしりょう #T35 #_4配合_4飼料
はいぶりっどしゃ #T35 #_6ハイブリッド_2車
はいてすて #KS #_3掃いて_2捨て
はきだめにつる #T35 #_5掃きだめに_2鶴
はくしゃをかけ #KS #_5拍車を_2かけ
はしにもぼう #T35 #_4箸にも_2棒
はっこうだいおーど #T35 #_4発光_5ダイオード
はとのふん #T35 #_3鳩の_2糞
はないきがあら #KY #_5鼻息が_2荒
はなのした #T35 #_3鼻の_2下
はにははを #CJ #_3歯には_2歯を
はやおきはさんもんのとく #T35 #_5早起きは_5三文の_2得
はらがすわ #R5 #_3腹が_2据わ
はらにすえかね #KS #_3腹に_4据えかね
はらをかかえ #KS #_3腹を_3抱え
はらをたて #KS #_3腹を_2立て
はらがた #T5 #_3腹が_1立
はりのむしろ #T35 #_3針の_3むしろ
はりはりなべ #T35 #_4ハリハリ_2鍋
はをくいしば #R5 #_2歯を_4食いしば
はんすうかんり #T30 #_4版数_3管理
はんとけいまわり #T35 #_2反_3時計_3回り
ばかとはさみはつかいよう #T35 #_3馬鹿と_4鋏は_5使いよう
ばきゃくをあらわ #S5 #_5馬脚を_3現
ばれんたいんでー #T35 #_6バレンタイン_2デー
ぱいづつみ #T35 #_2パイ_3包み
ぱんぷきんぱい #T35 #_5パンプキン_2パイ
ひにあぶらをそそ #G5 #_2火に_4油を_2注
ひっすかもく #T35 #_3必須_3科目
ひといきつ #K5 #_4一息_1つ
ひとのふりみ #KS #_3人の_2振り_1見
ひとはたあげ #KS #_4一旗_2あげ
ひとはだこいし #KY #_4人肌_3恋し
ひとめをしの #B5 #_4人目を_2忍
ひのきえ #KS #_2火の_2消え
ひもまたすずし #_2火も_2_また_3涼し
ひびやこうかいどう #CN #_3日比谷_6公会堂
ひゃくぶんはいっけんにし #K5 #_6百聞は_5一見に_1し
ひんすればどん #SX #_5貧すれば_2鈍
びーがた #T35 #_2B_2型
ふえふけどおど #R5 #_2笛_3吹けど_2踊
ふくごうしせつ #T35 #_4複合_3施設
ふくすいぼんにかえ #R5 #_4覆水_3盆に_2返
ふくそかいせき #T35 #_3複素_4解析
ふくやしょてん #KK #_3福家_4書店
ふたごたまがわ #CN #_3二子_4玉川
ふたをあけてみ #KS #_3ふたを_3開けて_1み
ふっきゅうもくてき #T35 #_5復旧_4目的
ふっこうもくてき #T35 #_4復興_4目的
ふとくていたすう #T35 #_5不特定_3多数
ふにおち #KS #_2腑に_2落ち
ふのすう #T35 #_2負の_2数
ふらんくみゅらー #KK #_4フランク_4ミュラー
ふりつづ #K5r #_2降り_2続
ふるもでるちぇんじ #T30 #_2フル_3モデル_4チェンジ
ぶしはくわねど #F06 #_3武士は_4食わねど
ぷらすしこう #T05 #_3プラス_3思考
ぷりーつかこう #T35 #_4プリーツ_3加工
へたなてっぽうかずうちゃあた #R5 #_3下手な_4鉄砲_2数_3打ちゃ_2当た
へんかんきー #T35 #_4変換_2キー
ぺーすはいぶん #T30 #_3ペース_4配分
ぺーすめーかー #T35 ペースメーカー
ほうりなげ #KS #_3放り_2投げ
ほとけのかおもさんど #T35 #_4仏の_3顔も_3三度
ほねをお #R5 #_3骨を_1折
ほんやくじょうきょう #T35 #_4翻訳_6状況
ぼうがいこうさく #T30 #_4妨害_4工作
ぼうけいじばん #T35 #_2某_5掲示版
ぼうずにくけりゃ #F06 #_3坊主_5憎けりゃ
ぼうにふ #R5 #_3棒に_1振
ぽいんとかんげん #T35 #_4ポイント_4還元
まいなすしこう #T05 #_4マイナス_3思考
まくのうちべんとう #T35 #_5幕の内_4弁当
まがさ #S5 #_2魔が_1差
まごにもいしょう #F06 #_4馬子にも_4衣装
まちがいさがし #T30 #_4間違い_3探し
まてばかいろのひよりあ #aru #_3待てば_4海路の_3日和_1あ
まとをい #KS #_3的を_1射
まるくおさめ #KS #_3丸く_3収め
まるちとぴっく #T35 #_3マルチ_4トピック
まんがきっさ #T35 #_3漫画_3喫茶 #_3マンガ_3喫茶 #_3まんが_3喫茶
まんざらでもな #KY #_6まんざらでも_1な
みいらとり #T35 #_3ミイラ_2取り
みずになが #S5 #_3水に_2流
みずのあわ #T35 #_3水の_2泡
みずをえたさかな #T35 #_3水を_2得た_3魚
みずをさ #S5 #_3水を_1差
みどりのひ #T35 #_4みどりの_1日
みにしみ #KSr #_2身に_2染み
みみにたこができ #KS #_3耳に_3タコが_2でき
みみをすま #SX #_3耳を_2すま
みもしらず #T35 #_2見も_3知らず
みをこに #SX #_2身を_2粉に
みんかんきぎょう #T35 #_4民間_4企業
むじんてんぽ #T35 #_3無人_3店舗
むせんらん #T35 #_3無線_2LAN
むせんれんらく #T30 #_3無線_4連絡
むだだま #T35 #_2無駄_2弾
むねをなでおろ #SX #_3胸を_2なで_2おろ
めいしんこうそく #CN #_4名神_4高速
めいどかふぇ #T35 #_3メイド_3カフェ
めいわくしごく #CN #_4迷惑_3至極
めがさめ #KS #_2目が_2覚め
めにーこあ #T35 #_3メニー_2コア
めにいこあ #T35 #_3メニイ_2コア
めにいれてもいた #KY #_2目に_4入れても_2痛
めにはめを #CJ #_3目には_2目を
めはくちほど #T05 #_2目は_2口_2ほど
めはくちほどにものをい #W5 #_2目は_5口ほどに_3物を_1言
もうけばなし #T35 #_3儲け_3話
もちはもちや #F06 #_3餅は_3餅屋
もとのもくあみ #T35 #_3元の_4木阿弥
ものいえばくちびるさむしあきのかぜ #T35 #_2物_3言えば_4唇_3寒し_3秋の_2風
ものはいいよう #T05 #_2物は_5言いよう
やすものがい #T30 #_4安物_2買い
やせのおおぐい #T35 #_3痩せの_4大食い
やまありたにあり #F14 #_4山あり_4谷あり
やまいはき #T35 #_4病は_1気
やまだでんき #KK #_3ヤマダ_3電器
ゆうべんはぎん #T35 #_5雄弁は_2銀
ゆうりょくかい #T35 #_5有力_2解
ゆかしたしんすい #T35 #_4床下_4浸水
ゆびきりげんまん #T35 #_4指切り_4げんまん
ゆるしをこ #U5 #_4許しを_1請
よこすくろーる #T30 #_2横_5スクロール
よこまき #T35 #_2横_2巻
よみとりせんよう #T35 #_4読み取り_4専用
よわきをたすけ #KS #_4弱きを_3助け
よわりめにたたりめ #T05 #_5弱り目に_4祟り目
らくとあいす #T35 #_3ラクト_3アイス
らじうむおんせん #T35 #_4ラジウム_4温泉
らちがあ #K5 #_3ラチが_1あ  #_3埓が_1明
りゅうがくさき #T35 #_5留学_2先
りょうやくくちににが #KY #_5良薬_3口に_2苦
りょうゆうならびた #T5 #_5両雄_4並び立
りょうゆうともにはた #T5 #_5両雄_4倶には_1立
りょこうだいりてん #T35 #_4旅行_5代理店
るいう゛ぃとん #T35 #_2ルイ_5ヴィトン
れいぎしらず #T35 #_3礼儀_3知らず
れじゃーしせつ #T35 #_4レジャー_3施設
ろーかるばんぐみ #T35 #_4ローカル_4番組
ろーまはいちにちにしてなら #KS #_4ローマは_7一日にして_2成ら
ろーまにつうず #CJ #_4ローマに_3通ず
ろうかぼうし #T35 #_3老化_3防止
ろじさいばい #T30 #_2露地_4栽培
わかれぎわ #T35 #_3別れ_2際
わがふりなお #S5 #_2我_2振り_2直
わざわいてんじてふくとな #S5 #_4禍_4転じて_3福と_1な
わしてどうぜず #CJ #_3和して_4同ぜず
わらびもち #T35 #_3わらび_2餅
わをかけ #KS #_2輪を_2かけ
#
#
しゃ #SVSUC*10 者
じ #SVSUC*10 時
ご #SVSUC*10 後
まえ #SVSUC*10 前
ごと #SVSUC*10 ごと 毎
き #SVSUC*10 機 器
ずみ #SVSUC*10 済み
りつ #SVSUC*10 率
つ #JS つ
かた #D2T35 方
#
\mofidy_freq がわ #T35 側 kill
がわ #SUC*250 側
\mofidy_freq かん #T35 間 kill
かん #SUC*250 間
ない #SUC*250 内
ごと #SUC*250 ごと #SUC*200 毎
#
#
いち #N04 一
に #N04 二
さん #N04 三
よん #N04 四
ご #N04 五
ろく #N04 六
なな #N04 七
はち #N04 八
きゅう #N04 九
#
ひゃく #N05 百
にひゃく #N05 二百
さんびゃく #N05 三百
よんひゃく #N05 四百
ごひゃく #N05 五百
ろっぴゃく #N05 六百
ななひゃく #N05 七百
はっぴゃく #N05 八百
きゅうひゃく #N05 九百
#
あそうぎ #N00 阿僧祇
ごうがしゃ #N00 恒河沙
なゆた #N00 那由多 那由他 奈由太
#
がた #D2KY 難 #D2KY*6 がた
づら #D2KY づら #D2KY*6 辛
やす #D2KY 易 #D2KY*645 やす
#
かんじが #SX 感じが
じ #JS*2 時
し #sxi2*400 し
#
# その他
#
#
そうぞうだに #T30 想像だに
よそうだに #T30 予想だに
#
！ #KJ !
” #OPEN " #CLOSE "
#＃ #KJ # #は品詞と解釈されるのでエスケープする方法を考える
＄ #KJ $
％ #KJ %
＆ #KJ &
’ #KJ '
、 #KJ*10 、 ， , ，
ー #KJ -
。 #KJ 。 ． .
： #KJ :
； #KJ ;
＝ #KJ =
？ #KJ ?
＠ #KJ @
＼ #KJ \\ ￥
」 #KJ ]
＾ #KJ ^
＿ #KJ _
‘ #KJ `
｜ #KJ |
＜ #OPEN <
＞ #CLOSE >
（ #OPEN (
） #CLOSE )
｛ #OPEN {
｝ #CLOSE }
〜 #KJ ~
「 #OPEN 「 『 〈 《 【
」 #CLOSE 」 』 〉 》 】
。。。 #KJ …
％ #JS %
