#
# Cannadicと互換性のある単語の辞書
# alt-cannadicに無い単語(更新作業中)
#
#
あいーだ #KK アイーダ
あおに #T35 青丹
あおによし #F14 青丹よし
あじゃいる #T05 アジャイル
あっせい #T30 アッセイ
あにめか #T30 アニメ化
あねは #JNS 姉歯
あのくたら #T35 阿耨多羅
あんとらせん #T35 アントラセン
いぇん #T35 ￥ 円
いそじん #T35 イソジン 磯陣
いみゅーたぶる #T05 イミュータブル
いりでっぽう #T35 入鉄砲
いんたーろいきん #T35 インターロイキン
うごう #T35 烏合
うっこん #T35 鬱金
うばすて #T35 姥捨
うまいり #T30 馬入
うまずら #T35 馬面 馬づら
うめに #T35 梅煮
うらら #T05 麗ら
えきしん #T35 液浸
えきそ #T35 エキソ
えきだし #T30 益出し
えきらく #T30 液絡
えっくすおーじゃん #T35 ＸＯ醤 XO醤
えんきょう #T35 塩橋
えんざいむのあっせい #T30 エンザイムノアッセイ
どちらにせよ #F12 どちらにせよ
おおいちばん #T35 大一番
おかつこく #CN 岡津古久
おてろ #KK オテロ
おもむろ #T05 徐
おわら #S5 終わら
かいじゅうだいずかい #T35 怪獣大図解
かいじゅうだいひゃっか #T35 怪獣大百科
かながた #T35 金型
しょうにかい #T35 小児科医
じゅんきょう #T35*200 准教
じょきょう #T35 助教
ざいむさんぴょう #T35 財務三表
すぎ #T35 過ぎ
かざりっけ #T35 飾りっ気
からめるそーす #T35 カラメルソース
かんがえどころ #T35 考えどころ 考え所
がおか #T35 ヶ丘
がくせいさん #T35 学生さん
きくところ #T05 聞くところ
きまんだ #KK キマンダ
きゅうき #T30 給気
きゅうぞう #T35 吸蔵
きょうこうせん #T35 京工繊
きょがくきゅう #T35 巨核球
きょん #JNS キョン
きわまりづき #T35 極月
きんひどろん #T35 キンヒドロン
ぎごしょく #T35 魏呉蜀
ぎょうじん #T35 行人
ぎんたま #T35 銀魂
くいたん #T35 杭端
くうしきぜくう #T35 空色是空
くずりゅうせん #T35 九頭竜閃
くにく #T35 狗肉
くらりてぃー #T35 クラリティー
けい #N2T35 系
けいしき #N2T35 形式
けつおう #T35 傑王
けんりゅう #T35 劍竜
げする #sxuru 解する
こうじきゅう #T35 好時給
こうやれん #KK 高野連
こじんわざ #T35 個人技
こまり #T35 困り
ごろん #F07 ごろん
さいこう #T30 催行
さいちょうせい #T30 再長生
さいとそる #T35 サイトソル
さいゆう #T35 最尤
さけるい #T35 酒類
さぜ #JNS 佐瀬
さて #F14 さて
さびどめ #T35 さび止め
さんたい #T35 三態
ざね #T35 実
しちぎー #T35 シチギー
しちょうせい #T35 死兆星
しばたま #T35 芝玉
しゃじょうあらし #T35 車上荒らし
しょうかんじゅう #T35 召喚獣
しょりん #T35 書林
しらきや #KK 白木屋
しんこくもれ #T30 申告漏れ
じぇねおん #KK ジェネオン
じゃぱねっと #KK ジャパネット
じさな #KY*150 辞さな
じょうざんき #T35 乗算器
すいぞっかん #T35 水族館
すみごこち #T35 住み心地
すぱったりんぐ #T35 スパッタリング
ずじ #T30 図示
せいいき #T35 整域
せいりゅうかく #KK 政竜閣
ぜらにゅーむ #T35 ゼラニューム
たこあげ #T30 凧上げ
たこう #T35 他行
たっくすへいぶん #T35 タックスヘイブン
たぬきも #T35*2 水豆児
たびくせ #T35 旅癖
たぷる #T35 タプル
たまらん #F06*100 たまらん
たません #T35 多摩線
たよりがい #T35 頼りがい 頼り甲斐
たんかひ #T35 単花被
たんかん #T35 タンカン
だいおういか #T35 ダイオウイカ
だいそん #T35 ダイソン
だるまさん #JN だるまさん
ちこうりゅう #T35 地衡流
ちゃんば #T35 チャンバ
ちゅう #N2T35 中
ちゅういち #T35 中一
ちゅうさん #T35 中三
ちゅうに #T35 中二
ちゅうにびょう #T35 中二病
ちょくびょう #T30 直描
ちょこぼ #T35 チョコボ
ちんそうだん #T35 珍走団
つかいはしり #T30 使いはしり
つづけ #D2KY つづけ #D2KY 続け
つみれじる #T35 つみれ汁
てんさいか #T35 転載可
でじる #T35 出汁
でまるちぷれくさ #T35 デマルチプレクサ
でむぱ #T05 デムパ
でんどろぐらむ #T35 デンドログラム
とくにん #T35*200 特任
とてもじゃな #KY とてもじゃな
とてもでは #KY とてもでは
ともあらい #T30 共洗い
どうき #T30 同期
どうちるい #T35 同値類
どくだけ #T35 毒茸
どしょうぼね #T35 土性骨
なすたちゅーむ #T35 ナスタチューム
なっせん #T35 捺染
ならず #T35 不成
なるにあ #T35 ナルニア
なんが #T35 軟臥
なほし #T35 直衣
なんきんまめ #T35 なんきんまめ
にりょうたい #T35 二量体
ねかふぇ #T35 ネカフェ
ねくろまいのーしす #T30 ネクロマイノーシス
はいちゅうりつ #T35 排中律
はしのすけ #JNM 橋之助
はたとせ #T35 二十歳
はたらきがい #T35 働き甲斐
はなしぶり #T35 話ぶり 話振り
はどろん #T35 ハドロン
はんえんけい #T35 攀縁茎
ばつげーむ #T30 罰ゲーム
ばはむーと #T35 バハムート
ばーてっくす #T35 バーテックス
ばりおん #T35 バリオン
ぱーこれーしょん #T35 パーコレーション
ひかか #R5 引かか
ひどろきのん #T35 ヒドロキノン
ひそうしゃ #T35 被葬者
ひゅーりすてぃくす #T35 ヒューリスティクス
ひょうかき #T35 評価機 評価器 評価期
ひんこんそう #T35 貧困層
びくりと #F14 びくりと
びざんつ #T35 ビザンツ
びすた #T35 ビスタ
びより #T35 日和
ぴたっと #F12 ピタッと ぴたっと
ぴぶろっと #T35 ピブロット
ふぁるすたっふ #KK ファルスタッフ
ふぃぶりげん #T35 フィブリゲン
ふえん #T35 浮堰
ふかいり #T05 深煎り
ふかぜり #T35 深芹
ふみば #T35 踏み場
ふらーれん #T35 フラーレン
ふりこ #M5r 降り込
ふろあがり #T35 風呂上がり
ふわっと #F14 ふわっと フワッと
ぷろこん #T35 プロコン
ぷろびっと #T35 プロビット
ぶようじょう #T35 無養生
へいきゅう #T35 閉球
へきさ #T35 ヘキサ
へんぶん #T35 変分
べきれい #T35 巾零
ぺぷちたーぜ #T35 ペプチターゼ
ほがい #T30 補外
ぼそっと #F14 ぼそっと ボソッと
ぼっと #T35 ボット
まいのうみ #JN 舞の海
まぐさ #T35 芻 蒭
まじれす #T30 マジレス
ませき #T35 魔石
まつ #T5 俟つ
まよそーす #T35 マヨソース
みずてん #T35 不見転
みみたこ #T35 耳胼胝
むしつかい #T35 蟲使い
むしひめさま #T35 虫姫さま
むしょうにん #T35 無承認
むすこさん #T35 息子さん
めいどさん #T35 メイドさん
めたぼ #T05 メタボ
めて #T35 馬手 右手
もっきつ #T35 勿吉
ものうい #T35 懶い
もるぼる #T35 モルボル
もんきり #T35 紋切り 紋切
やくゆ #T35 薬湯
ゆそつ #T35 輸卒
ゆてん #T35 油点
ゆとう #T35 湯桶
ゆにたり #T35 ユニタリ
ようとう #T35 羊頭
よすて #T35 世捨て
よりまし #T35 憑巫
よりゆき #JN 頼之
よんさま #JN ヨン様
らのべ #T35 ラノベ
らむう #T35 ラムウ
らぷたー #T35 ラプター
りあぷろ #T35 リアプロ
りせき #T30 離席
りゅうすう #T35 留数
りんし #T35 臨死
れいたいさい #T35 例大祭
ろーんち #T30 ローンチ
#
# 疑問副詞
なんどか #F14 なんどか #F14 何度か
いつか #F14 いつか #F14 何時か
なにか #F14 何か #F14 なにか
どこか #F14 どこか #F14 何処か
なぜか #F14 なぜか #F14 何故か
どうしてか #F14 どうしてか
#
# 時を表す副詞的な名詞
あした #F14 明日
あさ #F14 朝
あさって #F14 あさって 明後日
あと #F14 後 あと
いご #F14 以後
いぜん #F14 以前
いちじ #F14 一時
いちにちじゅう #F14 一日中
いま #F14 今
おとつい #F14 おとつい 一昨日
おととい #F14 おととい 一昨日
きのう #F14 昨日
きょう #F14 今日
こんど #F14 今度
さいきん #F14 最近
さくげつ #F14 昨月
しあさって #F14 しあさって 明明後日
すうじつ #F14 数日
つねひごろ #F14 常日頃
はんにち #F14 半日
ばん #F14 晩
ひとばんじゅう #F14 一晩中 #T35 一晩中
まいとし #F14 毎年
まいにち #F14 毎日
むかし #F14 昔
ひる #F14 昼
よる #F14 夜
んで #CJ んで
#
# コンピュータ
いんふぉしーく #T35 インフォシーク
ういるすかんせん #T35 #_4ウイルス_4感染
えくせる #T35 エクセル
えろさいと #T35 #_2エロ_3サイト
かおもじ #T35 顔文字
かぜはかせ #T35 風博士
きかんしすてむ #T35 #_3基幹_4システム
ぐーぐる #T35 グーグル
くみこみきき #T35 #_4組込_2機器 #_4組み込み_2機器
けっていぎ #T35 決定木
こまんどきー #T35 コマンドキー
こんぽーねんつ #T35 コンポーネンツ
さいんあうと #T30 サインアウト
さいんいん #T30 サインイン
さぶくらす #T35 サブクラス
しすてむかいはつ #T30 #_4システム_4開発
しすてむきばん #T35 #_4システム_3基盤
しゅうへんきき #T35 #_5周辺_2機器
じおしてぃーず #KK ジオシティーズ
じどうせいせい #T30 #_3自動_4生成
じゃすらっく #KK ジャスラック
じょうほうかでん #T35 #_5情報_3家電
じょうほうきき #T35 #_5情報_2機器
すかいぷ #T30 スカイプ
すきみんぐ #T35 スキミング
すらっしゅどっと #T35 スラッシュドット
すらど #T35 スラド
そふとかいはつ #T30 #_3ソフト_4開発
せいきばん #T35*115 正規版 正規盤
せつぞくかんきょう #T35 #_4接続_5環境
たてすくろーる #T30 #_2縦_5スクロール
つうしんいんふら #T35 #_4通信_4インフラ
とらっかー #T35 トラッカー
なーど #T35 ナード
ねんがじょうそふと #T35 #_6年賀状_3ソフト
ぱわぽ #T35 パワポ
びっととれんと #T35 ビットトレント
ふるすくりーん #T35 フルスクリーン
ぶるーれい #T35 ブルーレイ
ぷろくし #T30 プロクシ
もなど #T35 モナド
らいこす #T35 ライコス
りふぁら #T35 リファラ
りふれ #T35 リフレ
#
# 固有名詞
かんくう #T35 関空
かんてれ #KK 関テレ
かんふーはっする #T35 #_4カンフー_4ハッスル
くろねこやまと #KK クロネコヤマト
ぐっでい #KK グッデイ
こーえー #KK コーエー
ごーるでんいーぐるす #KK ゴールデンイーグルス
さんまるく #KK サンマルク
じぶり #KK ジブリ
じゃにーず #JN ジャニーズ
すかぱー #KK スカパー
すたじおじぶり #KK スタジオジブリ
すぽーつほうち #T35 スポーツ報知
せんとれあ #T35 セントレア
たっけん #KK 宅建
だいそー #KK ダイソー
つたや #KK TSUTAYA ツタヤ
てれあさ #KK テレ朝
てれとう #KK テレ東
でいりーすぽーつ #T35 #_4デイリー_4スポーツ
といざらす #KK トイザラス
とうほくらくてん #KK 東北楽天
とくしません #T35 徳島線
どとーる #KK ドトール
ないきすと #T30 ナイキスト
なんばーず #T30 ナンバーズ
にってれ #KK 日テレ
にんてんどー #T35 ニンテンドー
はうるのうごくしろ #T35 #_4ハウルの_3動く_2城
はろーわーく #KK ハローワーク
ぱなそにっく #KK パナソニック
ぱりだか #T30 パリダカ
びーとる #T35 ビートル
ぶっしゅ #JNM ブッシュ
ぶらっくじゃっく #JNM ブラックジャック
ほりぷろ #KK ホリプロ
まりお #JNM マリオ
まりおかーと #JNM #_3マリオ_3カート
まんぎょんぼんごう #T35 マンギョンボン号 万景峰号
まんつーまん #T30 マンツーマン
めーてれ #KK メ〜テレ
ゆうぱっく #T35 ゆうパック
らいぶどあ #KK ライブドア
らくてんいーぐるす #KK 楽天イーグルス
りすとばんど #T35 リストバンド
るふとはんざ #T35 ルフトハンザ
るんげくった #T35 ルンゲクッタ
るるいえ #CN ルルイエ
ろーりんぐすとーんず #T35 ローリングストーンズ
わーしゃるふろいど #T35 ワーシャルフロイド
#
# サッカー
さいどこうげき #T30 再度攻撃 サイド攻撃
#
きごう #KJ 〓 ↓ ↑ ← → 〒 ※ ▼ ▽ ▲ △ ■ □ ◆ ◇ ◎ ● ○ ★ ☆ § £ ¢ ￥ ℃ ″ ′ ° ♀ ♂ ∴ ∞ ≧ ≦ ≠ ÷ × ± 】 【 』 『 》 《 〉 〈 〕 〔 “ ‥ … ‖ ‐ ― 〇 〆 々 仝 〃 ゞ ゝ ヾ ヽ ￣ ¨ ｀ ´ ゜ ゛ ・ ＠ ＞ ＃ ％ ＆ ＊ 〜 ＄ ＝ ≒ ＜ ♪ − ＋ ／ ＼ ？ 」 ！ ｜ 「 ｝ ］ ｛ ［ ； ） （ ” ’ ． 、 ‘ ＿ ， ー ： ≡ ♭ ＾ - 。 Ц ⌒ ¶ ‡ ∵ ヶ ≫ ∧ ∨ ¬ ∠ ≪ ∝ ∫ Å ‰ † ∪
／ #KJ ・
「 #KJ [
」 #KJ ]
* #KJ * ×
+ #KJ +
/ #KJ / ／ ÷
` #KJ ｀ ‘
\ #KJ \\ ＼ ￥
#
# 田畑セクション
すれ #T35 スレ
みにもに #T35 ミニモニ
にょろ #T35 ~
きんらんせんり #T35 金蘭千里
ちゃんねらー #T35 チャンネラー
ぎこねこ #T35 (°Д°)
# KMC セクション Cannadicに取りこまれると困るもの
かんぱいさんしょう #T35 乾杯三唱
すまぶら #T30 スマブラ
さけうま #T30*2 酒旨
さむらいだましい #T35 侍魂
とも #T35 強敵
へんぐばんど #T35 変愚蛮怒
